==> scdlbot-0.9.26.tar.gz: scdlbot-0.9.26/scdlbot/texts/help.tg.md <==
Hi! I download and send audios from videos/tracks/sets/albums in *MP3 128 kbps* with tags and artwork. Files over 50 MB are split into parts due to Telegram Bot API limit.

*Usage:*
_Send or forward_ a text message containing links and I will:
• In *Download* mode: download every link I support (or use `/dl <links>`)
• In *Links* mode: show direct download URLs for every link (or use `/link <links>`)
• In *Ask* mode: scan for supported links and ask you to choose download or links
• Use /settings to select working mode for messages *without command*.
• Use /settings to toggle *Captions*.
• [Privacy mode](https://core.telegram.org/bots#privacy-mode) is _disabled_, so I scan every group message.
• Supported links and resources:
*SoundCloud*: tracks/playlists/pages with private widgets
*Bandcamp*: tracks/albums/custom links
*YouTube*: videos/playlists/_not_ lives
*Yandex.Music*: tracks/albums
*Mixcloud, Vimeo and* [almost everything from this list](https://rg3.github.io/youtube-dl/supportedsites.html), but no VK music

*Example message:*
`Hey, check this out! https://m.soundcloud.com/falling-ethics/jk-flesh-static-demon-fexelvn004 and also https://shitmat.bandcamp.com/track/amen-babylon-2016-mix and youtu.be/Mdzy5RKn434`

[🌟 Star me on GitHub!](https://github.com/gpchelkin/scdlbot) | [⚠️ Report an issue](https://github.com/gpchelkin/scdlbot/issues)
👨🏻‍💻 Developed by *@gpchelkin* | [🐝 Homepage](https://pchelk.in/)
👩🏻‍🎨 Logo by `@lowonbudget` | [🖼️ Behance](https://www.behance.net/lowonbudget)
🎶 Inspired by @electrocircle | [⚡⚫ Channel](https://t.me/Eklight)

==> scdlbot-0.13.5.1.tar.gz: scdlbot-0.13.5.1/scdlbot/texts/help.tg.md <==
Hi! I download and send audios from videos/tracks/sets/albums in *MP3 128 kbps* with tags and artwork. Files over 50 MB are split into parts due to Telegram Bot API limit.

*Usage:*
_Send or forward_ a text message containing links and I will:
• In *Download* mode: download every link I support (or use `/dl <links>`)
• In *Links* mode: show direct download URLs for every link (or use `/link <links>`)
• In *Ask* mode: scan for supported links and ask you to choose download or links
• Use /settings to select working mode for messages *without command*.
• Use /settings to toggle *Captions*.
• [Privacy mode](https://core.telegram.org/bots#privacy-mode) is _disabled_, so I scan every group message.
• Supported links and resources:
*SoundCloud*: tracks/playlists/pages with private widgets
*Bandcamp*: tracks/albums/custom links
*YouTube*: videos/playlists/_not_ lives
*Yandex.Music*: tracks/albums
*Mixcloud, Vimeo and* [almost everything from this list](https://ytdl-org.github.io/youtube-dl/supportedsites.html), but no VK music

*Example message:*
`Hey, check this out! https://m.soundcloud.com/falling-ethics/jk-flesh-static-demon-fexelvn004 and also https://shitmat.bandcamp.com/track/amen-babylon-2016-mix and youtu.be/Mdzy5RKn434`

👨🏻‍💻 *Developed by @gpchelkin*:
[🐝 Channel](https://t.me/ggpchelkin) | [🐝 Homepage](https://pchelk.in)
[🌟 Star me on GitHub!](https://github.com/gpchelkin/scdlbot) | [⚠️ Report an issue](https://github.com/gpchelkin/scdlbot/issues)
💵 Support development:
[PayPal](http://paypal.me/ggpchelkin/200) | [Ko-fi](https://ko-fi.com/gpchelkin) | [Tinkoff](https://www.tinkoff.ru/sl/Acd7Jamf4YM) | [Yandex.Money](http://money.yandex.ru/to/41001421333857/200)

👩🏻‍🎨 Logo by `@lowonbudget` | [🖼️ Behance](https://www.behance.net/lowonbudget)
🎶 Inspired by `@electrocircle` | [⚡⚫ Channel](https://t.me/Eklight)
